package cn.fastfun.controller.api;

import cn.fastfun.controller.param.UserPassWordParam;
import cn.fastfun.service.SysUserService;
import cn.fastfun.service.UtilService;
import cn.fastfun.service.entity.SysUser;
import com.bridge.dto.*;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.util.DigestUtils;
import org.springframework.util.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.Arrays;
import java.util.Date;

/**
 * @author Bridge AutoGen
 */
@Api(tags = {"系统账号"})
@RestController
@RequestMapping("/api/v1/sysuser")
public class ApiSysUserController {
    //业务类
    @Resource
    SysUserService sysUserService;

    @Resource
    UtilService utilService;

    /**
     * 数据保存
     */
    @ApiOperation(value = "保存信息")
    @RequestMapping(value = "save", method = RequestMethod.POST)
    public ApiDTO save(@RequestBody @ApiParam(name = "系统账号对象", value = "传入json格式", required = true) SysUser entity) {
        SysUser tmp = sysUserService.save(entity);
        return ApiDTO.ok("保存成功", tmp);
    }

    @ApiOperation(value = "查询信息")
    @RequestMapping(value = "get", method = RequestMethod.POST)
    public ApiDTO get(@RequestBody @ApiParam(name = "系统账号id", required = true) IdParam param) {
        return ApiDTO.ok("查询成功！", sysUserService.get(param.getId()));
    }

    @ApiOperation(value = "修改账号密码")
    @PostMapping("update/password")
    public ApiDTO updatePassWord(@Validated @RequestBody UserPassWordParam param) {
        if (StringUtils.isEmpty(param.getId())) return ApiDTO.error("账号ID错误");
        if (!param.getNewPassWord().equals(param.getConfirmPasWord()))
            return ApiDTO.error("修改密码和确认密码不一致!");

        SysUser sysUser = sysUserService.getOne(QueryParamExp.eq("id", param.getId()));
        if (!sysUser.getUserPass().equals(DigestUtils.md5DigestAsHex(param.getOldPassWord().getBytes())))
            return ApiDTO.error("当前密码错误!");
        sysUser.setUserPass(DigestUtils.md5DigestAsHex(param.getNewPassWord().getBytes()));
        sysUserService.save(sysUser);
        if (param.getId().equals(utilService.getUserId()))
            utilService.resetLoginUser(sysUser, new Date());
        return ApiDTO.ok("密码修改成功!");
    }

    @ApiOperation(value = "删除信息")
    @RequestMapping(value = "delete", method = RequestMethod.POST)
    public ApiDTO delete(@RequestBody @ApiParam(name = "系统账号id", required = true) IdParam param) {
        String id = param.getId();
        sysUserService.delete(Arrays.asList(id.split(",")));
        return ApiDTO.ok();
    }

    @ApiOperation(value = "分页搜索")
    @RequestMapping(value = "pageQuery", method = RequestMethod.POST)
    public ApiPageDTO pageQuery(@RequestBody QueryParam param) {
        return new ApiPageDTO(null, sysUserService.findByParam(param));
    }

}